## `.env` 文件格式

若要运行 `usage_remote.py` 或 `usage_smithery.py`，需在当前路径创建 `.env` 文件。格式如下：

```
DEEPSEEK_API_URL=https://api.deepseek.com/v1
DEEPSEEK_API_KEY=
SMITHERY_API_KEY=
```

说明：

- `DEEPSEEK_API_KEY` 需到 [deepseek](https://platform.deepseek.com/) 申请
- `SMITHERY_API_KEY` 需到 [smithery](https://smithery.ai/server/@luochang212/card-magic-mcp) 申请
